@@ -2,7 +2,7 @@
 # Re-built by Itz-fork
 # Project: Gofile2
 import aiohttp
-from .errors import is_valid_token, InvalidToken,JobFailed, ResponseError
+from .errors import is_valid_token, InvalidToken, JobFailed, ResponseError
 
 
 class Async_Gofile:
@@ -51,7 +51,7 @@ class Async_Gofile:
                 return await self._api_resp_handler(server_resp)
             except Exception as e:
                 await self.__close_session(session)
-                raise JobFailed(f"Cannot Continue due to: {e}")
+                raise JobFailed(f"Error Happend: {e} \n\nReport this at ----> https://github.com/Itz-fork/Gofile2/issues")
     
     async def get_Account(self, check_account=False):
         """
@@ -79,7 +79,7 @@ class Async_Gofile:
                     return await self._api_resp_handler(get_account_resp)
             except Exception as e:
                 await self.__close_session(session)
-                raise JobFailed(f"Cannot Continue due to: {e}")
+                raise JobFailed(f"Error Happend: {e} \n\nReport this at ----> https://github.com/Itz-fork/Gofile2/issues")
         
     async def upload(self,file: str, folderId: str = None, description: str = None, password: str = None, tags: str = None, expire: int = None):
         """
@@ -94,7 +94,7 @@ class Async_Gofile:
             tags (optional) - Tags for the folder. If multiple tags, seperate them with comma. Not applicable if you specify a folderId
             expire (optional) - Expiration date of the folder. Must be in the form of unix timestamp. Not applicable if you specify a folderId
         """
-        server = self.get_Server()["server"]
+        server = await self.get_Server()["server"]
         if password != None and len(password) < 4:
             raise ValueError("Password Length must be greater than 4")
         
@@ -117,7 +117,7 @@ class Async_Gofile:
                 return await self._api_resp_handler(upload_file)
             except Exception as e:
                 await self.__close_session(session)
-                raise JobFailed(f"Cannot Continue due to: {e}")
+                raise JobFailed(f"Error Happend: {e} \n\nReport this at ----> https://github.com/Itz-fork/Gofile2/issues")
 
     async def create_folder(self, parentFolderId, folderName):
         """
@@ -145,7 +145,7 @@ class Async_Gofile:
                 return await self._api_resp_handler(folder_resp)
             except Exception as e:
                 await self.__close_session(session)
-                raise JobFailed(f"Cannot Continue due to: {e}")
+                raise JobFailed(f"Error Happend: {e} \n\nReport this at ----> https://github.com/Itz-fork/Gofile2/issues")
     
     async def set_folder_options(self, folderId, option, value):
         """
@@ -180,7 +180,7 @@ class Async_Gofile:
                 return await self._api_resp_handler(set_folder_resp)
             except Exception as e:
                 await self.__close_session(session)
-                raise JobFailed(f"Cannot Continue due to: {e}")
+                raise JobFailed(f"Error Happend: {e} \n\nReport this at ----> https://github.com/Itz-fork/Gofile2/issues")
 
     async def delete_content(self, contentId):
         """
@@ -206,4 +206,4 @@ class Async_Gofile:
                 return await self._api_resp_handler(del_content_resp)
             except Exception as e:
                 await self.__close_session(session)
-                raise JobFailed(f"Cannot Continue due to: {e}")
\ No newline at end of file
+                raise JobFailed(f"Error Happend: {e} \n\nReport this at ----> https://github.com/Itz-fork/Gofile2/issues")
\ No newline at end of file
